summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMark Doffman <mark.doffman@codethink.co.uk>2013-09-26 09:20:47 +0000
committerMark Doffman <mark.doffman@codethink.co.uk>2013-09-26 09:25:38 +0000
commitdea21a86c94ec16af9a286966c69a7baec977372 (patch)
treea6152ad63e6346d100508e10df320424e6633f0c
parent8a3efbe1db7398a0e6a47c120daf76dc5aaa906c (diff)
downloadlinux-baserock/markdoffman/cephroot.tar.gz
Rename function root_nfs_parse_addr to root_parse_addrbaserock/markdoffman/cephroot
to reflect its use in parsing an address for both NFS and CEPH root. Signed-off-by: Mark Doffman <mark.doffman@codethink.co.uk>
-rw-r--r--fs/ceph/root.c6
-rw-r--r--fs/nfs/nfsroot.c4
-rw-r--r--include/linux/nfs_fs.h2
-rw-r--r--net/ipv4/ipconfig.c6
4 files changed, 9 insertions, 9 deletions
diff --git a/include/linux/nfs_fs.h b/include/linux/nfs_fs.h
index fc01d5cb4cf1..5d465163b625 100644
--- a/include/linux/nfs_fs.h
+++ b/include/linux/nfs_fs.h
@@ -405,7 +405,7 @@ static inline void nfs_display_fhandle(const struct nfs_fh *fh,
*/
extern int nfs_root_data(char **root_device, char **root_data); /*__init*/
/* linux/net/ipv4/ipconfig.c: trims ip addr off front of name, too. */
-extern __be32 root_nfs_parse_addr(char *name); /*__init*/
+extern __be32 root_parse_addr(char *name); /*__init*/
/*
* linux/fs/nfs/file.c
diff --git a/net/ipv4/ipconfig.c b/net/ipv4/ipconfig.c
index feaf2143c55e..d34203a2f9eb 100644
--- a/net/ipv4/ipconfig.c
+++ b/net/ipv4/ipconfig.c
@@ -140,7 +140,7 @@ __be32 ic_addrservaddr = NONE; /* IP Address of the IP addresses'server */
__be32 ic_servaddr = NONE; /* Boot server IP address */
-__be32 root_server_addr = NONE; /* Address of NFS server */
+__be32 root_server_addr = NONE; /* Address of NFS or CEPH server */
u8 root_server_path[256] = { 0, }; /* Path to mount as root */
__be32 ic_dev_xid; /* Device under configuration */
@@ -1337,7 +1337,7 @@ static const struct file_operations pnp_seq_fops = {
* need to have root_server_addr set _before_ IPConfig gets called as it
* can override it.
*/
-__be32 __init root_nfs_parse_addr(char *name)
+__be32 __init root_parse_addr(char *name)
{
__be32 addr;
int octets = 0;
@@ -1491,7 +1491,7 @@ static int __init ip_auto_config(void)
ic_dev = ic_first_dev->dev;
}
- addr = root_nfs_parse_addr(root_server_path);
+ addr = root_parse_addr(root_server_path);
if (root_server_addr == NONE)
root_server_addr = addr;
diff --git a/fs/ceph/root.c b/fs/ceph/root.c
index 2f790df3f473..16d8f24d9b67 100644
--- a/fs/ceph/root.c
+++ b/fs/ceph/root.c
@@ -18,7 +18,7 @@
#include <linux/ceph/ceph_root.h>
/* linux/net/ipv4/ipconfig.c: trims ip addr off front of name, too. */
-extern __be32 root_nfs_parse_addr(char *name); /*__init*/
+extern __be32 root_parse_addr(char *name); /*__init*/
#define MAXPATHLEN 1024
@@ -89,10 +89,10 @@ static int __init ceph_root_setup(char *line)
strlcpy(ceph_root_params, line, sizeof(ceph_root_params));
/*
* Note: root_nfs_parse_addr() removes the server-ip from
* ceph_root_params, if it exists.
*/
- root_server_addr = root_nfs_parse_addr(ceph_root_params);
+ root_server_addr = root_parse_addr(ceph_root_params);
return 1;
}
@@ -89,10 +89,10 @@ static int __init ceph_root_setup(char *line)
strlcpy(ceph_root_params, line, sizeof(ceph_root_params));
/*
- * Note: root_nfs_parse_addr() removes the server-ip from
+ * root_parse_addr() removes the server-ip from
* ceph_root_params, if it exists.
*/
diff --git a/fs/nfs/nfsroot.c b/fs/nfs/nfsroot.c
index cd3c910d2d12..e413e5055de9 100644
--- a/fs/nfs/nfsroot.c
+++ b/fs/nfs/nfsroot.c
@@ -144,10 +144,10 @@ static int __init nfs_root_setup(char *line)
* Extract the IP address of the NFS server containing our
* root file system, if one was specified.
*
* Note: root_nfs_parse_addr() removes the server-ip from
* nfs_root_parms, if it exists.
*/
- root_server_addr = root_nfs_parse_addr(nfs_root_parms);
+ root_server_addr = root_parse_addr(nfs_root_parms);
return 1;
}
@@ -144,10 +144,10 @@ static int __init nfs_root_setup(char *line)
* root file system, if one was specified.
*
- * Note: root_nfs_parse_addr() removes the server-ip from
+ * Note: root_parse_addr() removes the server-ip from
* nfs_root_parms, if it exists.
*/